# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from v4_proto.dydxprotocol.vest import tx_pb2 as dydxprotocol_dot_vest_dot_tx__pb2


class MsgStub(object):
    """Msg defines the Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SetVestEntry = channel.unary_unary(
                '/dydxprotocol.vest.Msg/SetVestEntry',
                request_serializer=dydxprotocol_dot_vest_dot_tx__pb2.MsgSetVestEntry.SerializeToString,
                response_deserializer=dydxprotocol_dot_vest_dot_tx__pb2.MsgSetVestEntryResponse.FromString,
                )
        self.DeleteVestEntry = channel.unary_unary(
                '/dydxprotocol.vest.Msg/DeleteVestEntry',
                request_serializer=dydxprotocol_dot_vest_dot_tx__pb2.MsgDeleteVestEntry.SerializeToString,
                response_deserializer=dydxprotocol_dot_vest_dot_tx__pb2.MsgDeleteVestEntryResponse.FromString,
                )


class MsgServicer(object):
    """Msg defines the Msg service.
    """

    def SetVestEntry(self, request, context):
        """SetVestEntry sets a VestEntry in state.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteVestEntry(self, request, context):
        """DeleteVestEntry deletes a VestEntry from state.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SetVestEntry': grpc.unary_unary_rpc_method_handler(
                    servicer.SetVestEntry,
                    request_deserializer=dydxprotocol_dot_vest_dot_tx__pb2.MsgSetVestEntry.FromString,
                    response_serializer=dydxprotocol_dot_vest_dot_tx__pb2.MsgSetVestEntryResponse.SerializeToString,
            ),
            'DeleteVestEntry': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteVestEntry,
                    request_deserializer=dydxprotocol_dot_vest_dot_tx__pb2.MsgDeleteVestEntry.FromString,
                    response_serializer=dydxprotocol_dot_vest_dot_tx__pb2.MsgDeleteVestEntryResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dydxprotocol.vest.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the Msg service.
    """

    @staticmethod
    def SetVestEntry(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dydxprotocol.vest.Msg/SetVestEntry',
            dydxprotocol_dot_vest_dot_tx__pb2.MsgSetVestEntry.SerializeToString,
            dydxprotocol_dot_vest_dot_tx__pb2.MsgSetVestEntryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteVestEntry(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dydxprotocol.vest.Msg/DeleteVestEntry',
            dydxprotocol_dot_vest_dot_tx__pb2.MsgDeleteVestEntry.SerializeToString,
            dydxprotocol_dot_vest_dot_tx__pb2.MsgDeleteVestEntryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
