# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/clob/clob_pair.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!dydxprotocol/clob/clob_pair.proto\x12\x11\x64ydxprotocol.clob\"-\n\x15PerpetualClobMetadata\x12\x14\n\x0cperpetual_id\x18\x01 \x01(\r\"A\n\x10SpotClobMetadata\x12\x15\n\rbase_asset_id\x18\x01 \x01(\r\x12\x16\n\x0equote_asset_id\x18\x02 \x01(\r\"\xef\x03\n\x08\x43lobPair\x12\n\n\x02id\x18\x01 \x01(\r\x12K\n\x17perpetual_clob_metadata\x18\x02 \x01(\x0b\x32(.dydxprotocol.clob.PerpetualClobMetadataH\x00\x12\x41\n\x12spot_clob_metadata\x18\x03 \x01(\x0b\x32#.dydxprotocol.clob.SpotClobMetadataH\x00\x12\x1a\n\x12step_base_quantums\x18\x04 \x01(\x04\x12\x19\n\x11subticks_per_tick\x18\x05 \x01(\r\x12#\n\x1bquantum_conversion_exponent\x18\x06 \x01(\x11\x12\x32\n\x06status\x18\x07 \x01(\x0e\x32\".dydxprotocol.clob.ClobPair.Status\"\xaa\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x11\n\rSTATUS_ACTIVE\x10\x01\x12\x11\n\rSTATUS_PAUSED\x10\x02\x12\x16\n\x12STATUS_CANCEL_ONLY\x10\x03\x12\x14\n\x10STATUS_POST_ONLY\x10\x04\x12\x17\n\x13STATUS_INITIALIZING\x10\x05\x12\x1b\n\x17STATUS_FINAL_SETTLEMENT\x10\x06\x42\n\n\x08metadataB8Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.clob.clob_pair_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/types'
  _globals['_PERPETUALCLOBMETADATA']._serialized_start=56
  _globals['_PERPETUALCLOBMETADATA']._serialized_end=101
  _globals['_SPOTCLOBMETADATA']._serialized_start=103
  _globals['_SPOTCLOBMETADATA']._serialized_end=168
  _globals['_CLOBPAIR']._serialized_start=171
  _globals['_CLOBPAIR']._serialized_end=666
  _globals['_CLOBPAIR_STATUS']._serialized_start=484
  _globals['_CLOBPAIR_STATUS']._serialized_end=654
# @@protoc_insertion_point(module_scope)
